pixhost-uploader
================

Unofficial Python 3.2+ upload client for pixhost.org image sharing
website.

Usage
-----

.. code::

    import pixhostuploader as pixhost

    uploaded = pixhost.upload('image.jpg')

    print(uploaded)

